@@ -308,7 +308,7 @@ def normalize_geospatial_coordinates(
     geospatial_coordinates[1] = geospatial_coordinates[1] * 2 - 1
     # Now create a grid of the coordinates
     # Have to do it for each individual example in the batch, and zip together x and y for it
-    to_concat = []
+    solid_tensor = None
     for idx in range(len(geospatial_coordinates[0])):
         x = torch.from_numpy(geospatial_coordinates[0][idx])
         y = torch.from_numpy(geospatial_coordinates[1][idx])
@@ -316,10 +316,13 @@ def normalize_geospatial_coordinates(
         pos = torch.stack(grid, dim=-1)
         encoded_position = fourier_encode(pos, **kwargs)
         encoded_position = einops.rearrange(encoded_position, "... n d -> ... (n d)")
-        to_concat.append(encoded_position)
+        if solid_tensor is None:
+            solid_tensor = torch.zeros(
+                len(geospatial_coordinates[0]), *encoded_position.size(), dtype=x.dtype
+            )
+        solid_tensor[idx] = encoded_position
 
-    encoded_position = torch.stack(to_concat, dim=0)
-    return encoded_position
+    return solid_tensor
 
 
 def encode_year(
@@ -427,6 +430,8 @@ def fourier_encode(
     scales = scales[(*((None,) * (len(x.shape) - 1)), Ellipsis)]
 
     x = x * scales * pi
-    x = x.sin() if sine_only else torch.cat([x.sin(), x.cos()], dim=-1)
-    x = torch.cat((x, orig_x), dim=-1)
+    if sine_only:
+        x = torch.cat((x.sin(), orig_x), dim=-1)
+    else:
+        x = torch.cat((x.sin(), x.cos(), orig_x), dim=-1)
     return x
